import datetime

from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Link(_message.Message):
    __slots__ = ("id", "user_id", "slug", "title", "ios_url", "android_url", "web_url", "fallback_url", "huawei_url", "amazon_url", "windows_url", "macos_url", "app_name", "app_icon_url", "description", "is_active", "total_clicks", "created_at", "updated_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    SLUG_FIELD_NUMBER: _ClassVar[int]
    TITLE_FIELD_NUMBER: _ClassVar[int]
    IOS_URL_FIELD_NUMBER: _ClassVar[int]
    ANDROID_URL_FIELD_NUMBER: _ClassVar[int]
    WEB_URL_FIELD_NUMBER: _ClassVar[int]
    FALLBACK_URL_FIELD_NUMBER: _ClassVar[int]
    HUAWEI_URL_FIELD_NUMBER: _ClassVar[int]
    AMAZON_URL_FIELD_NUMBER: _ClassVar[int]
    WINDOWS_URL_FIELD_NUMBER: _ClassVar[int]
    MACOS_URL_FIELD_NUMBER: _ClassVar[int]
    APP_NAME_FIELD_NUMBER: _ClassVar[int]
    APP_ICON_URL_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    IS_ACTIVE_FIELD_NUMBER: _ClassVar[int]
    TOTAL_CLICKS_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    user_id: str
    slug: str
    title: str
    ios_url: str
    android_url: str
    web_url: str
    fallback_url: str
    huawei_url: str
    amazon_url: str
    windows_url: str
    macos_url: str
    app_name: str
    app_icon_url: str
    description: str
    is_active: bool
    total_clicks: int
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., user_id: _Optional[str] = ..., slug: _Optional[str] = ..., title: _Optional[str] = ..., ios_url: _Optional[str] = ..., android_url: _Optional[str] = ..., web_url: _Optional[str] = ..., fallback_url: _Optional[str] = ..., huawei_url: _Optional[str] = ..., amazon_url: _Optional[str] = ..., windows_url: _Optional[str] = ..., macos_url: _Optional[str] = ..., app_name: _Optional[str] = ..., app_icon_url: _Optional[str] = ..., description: _Optional[str] = ..., is_active: bool = ..., total_clicks: _Optional[int] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class ListLinksRequest(_message.Message):
    __slots__ = ("page", "per_page")
    PAGE_FIELD_NUMBER: _ClassVar[int]
    PER_PAGE_FIELD_NUMBER: _ClassVar[int]
    page: int
    per_page: int
    def __init__(self, page: _Optional[int] = ..., per_page: _Optional[int] = ...) -> None: ...

class ListLinksResponse(_message.Message):
    __slots__ = ("links", "total", "page", "per_page")
    LINKS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    PER_PAGE_FIELD_NUMBER: _ClassVar[int]
    links: _containers.RepeatedCompositeFieldContainer[Link]
    total: int
    page: int
    per_page: int
    def __init__(self, links: _Optional[_Iterable[_Union[Link, _Mapping]]] = ..., total: _Optional[int] = ..., page: _Optional[int] = ..., per_page: _Optional[int] = ...) -> None: ...

class CreateLinkRequest(_message.Message):
    __slots__ = ("slug", "title", "ios_url", "android_url", "web_url", "fallback_url", "huawei_url", "amazon_url", "windows_url", "macos_url", "app_name", "app_icon_url", "description")
    SLUG_FIELD_NUMBER: _ClassVar[int]
    TITLE_FIELD_NUMBER: _ClassVar[int]
    IOS_URL_FIELD_NUMBER: _ClassVar[int]
    ANDROID_URL_FIELD_NUMBER: _ClassVar[int]
    WEB_URL_FIELD_NUMBER: _ClassVar[int]
    FALLBACK_URL_FIELD_NUMBER: _ClassVar[int]
    HUAWEI_URL_FIELD_NUMBER: _ClassVar[int]
    AMAZON_URL_FIELD_NUMBER: _ClassVar[int]
    WINDOWS_URL_FIELD_NUMBER: _ClassVar[int]
    MACOS_URL_FIELD_NUMBER: _ClassVar[int]
    APP_NAME_FIELD_NUMBER: _ClassVar[int]
    APP_ICON_URL_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    slug: str
    title: str
    ios_url: str
    android_url: str
    web_url: str
    fallback_url: str
    huawei_url: str
    amazon_url: str
    windows_url: str
    macos_url: str
    app_name: str
    app_icon_url: str
    description: str
    def __init__(self, slug: _Optional[str] = ..., title: _Optional[str] = ..., ios_url: _Optional[str] = ..., android_url: _Optional[str] = ..., web_url: _Optional[str] = ..., fallback_url: _Optional[str] = ..., huawei_url: _Optional[str] = ..., amazon_url: _Optional[str] = ..., windows_url: _Optional[str] = ..., macos_url: _Optional[str] = ..., app_name: _Optional[str] = ..., app_icon_url: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...

class GetLinkRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class UpdateLinkRequest(_message.Message):
    __slots__ = ("id", "slug", "title", "ios_url", "android_url", "web_url", "fallback_url", "is_active")
    ID_FIELD_NUMBER: _ClassVar[int]
    SLUG_FIELD_NUMBER: _ClassVar[int]
    TITLE_FIELD_NUMBER: _ClassVar[int]
    IOS_URL_FIELD_NUMBER: _ClassVar[int]
    ANDROID_URL_FIELD_NUMBER: _ClassVar[int]
    WEB_URL_FIELD_NUMBER: _ClassVar[int]
    FALLBACK_URL_FIELD_NUMBER: _ClassVar[int]
    IS_ACTIVE_FIELD_NUMBER: _ClassVar[int]
    id: str
    slug: str
    title: str
    ios_url: str
    android_url: str
    web_url: str
    fallback_url: str
    is_active: bool
    def __init__(self, id: _Optional[str] = ..., slug: _Optional[str] = ..., title: _Optional[str] = ..., ios_url: _Optional[str] = ..., android_url: _Optional[str] = ..., web_url: _Optional[str] = ..., fallback_url: _Optional[str] = ..., is_active: bool = ...) -> None: ...

class DeleteLinkRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeleteLinkResponse(_message.Message):
    __slots__ = ("success", "message")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    success: bool
    message: str
    def __init__(self, success: bool = ..., message: _Optional[str] = ...) -> None: ...

class CheckSlugRequest(_message.Message):
    __slots__ = ("slug",)
    SLUG_FIELD_NUMBER: _ClassVar[int]
    slug: str
    def __init__(self, slug: _Optional[str] = ...) -> None: ...

class CheckSlugResponse(_message.Message):
    __slots__ = ("available", "slug")
    AVAILABLE_FIELD_NUMBER: _ClassVar[int]
    SLUG_FIELD_NUMBER: _ClassVar[int]
    available: bool
    slug: str
    def __init__(self, available: bool = ..., slug: _Optional[str] = ...) -> None: ...



"""Go2 SDK Errors."""

from typing import Any
import grpc


class Go2Error(Exception):
    """Base exception for Go2 SDK errors."""

    def __init__(self, message: str, code: grpc.StatusCode = grpc.StatusCode.UNKNOWN):
        super().__init__(message)
        self.code = code
        self.message = message


class AuthenticationError(Go2Error):
    """Raised when authentication fails (invalid API key)."""

    def __init__(self, message: str = "Invalid or missing API key"):
        super().__init__(message, grpc.StatusCode.UNAUTHENTICATED)


class NotFoundError(Go2Error):
    """Raised when a resource is not found."""

    def __init__(self, message: str = "Resource not found"):
        super().__init__(message, grpc.StatusCode.NOT_FOUND)


class PermissionDeniedError(Go2Error):
    """Raised when permission is denied."""

    def __init__(self, message: str = "Permission denied"):
        super().__init__(message, grpc.StatusCode.PERMISSION_DENIED)


class ValidationError(Go2Error):
    """Raised when input validation fails."""

    def __init__(self, message: str = "Invalid input"):
        super().__init__(message, grpc.StatusCode.INVALID_ARGUMENT)


class RateLimitError(Go2Error):
    """Raised when rate limit is exceeded."""

    def __init__(self, message: str = "Rate limit exceeded"):
        super().__init__(message, grpc.StatusCode.RESOURCE_EXHAUSTED)


def wrap_error(error: Any) -> Go2Error:
    """Convert a gRPC error to a Go2 SDK error."""
    if not isinstance(error, grpc.RpcError):
        return Go2Error(str(error))

    code = error.code()
    message = error.details() or str(error)

    if code == grpc.StatusCode.UNAUTHENTICATED:
        return AuthenticationError(message)
    elif code == grpc.StatusCode.NOT_FOUND:
        return NotFoundError(message)
    elif code == grpc.StatusCode.PERMISSION_DENIED:
        return PermissionDeniedError(message)
    elif code == grpc.StatusCode.INVALID_ARGUMENT:
        return ValidationError(message)
    elif code == grpc.StatusCode.RESOURCE_EXHAUSTED:
        return RateLimitError(message)
    else:
        return Go2Error(message, code)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: links/v1/links.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'links/v1/links.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14links/v1/links.proto\x12\x08links.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa3\x03\n\x04Link\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x0c\n\x04slug\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\x12\x0f\n\x07ios_url\x18\x05 \x01(\t\x12\x13\n\x0b\x61ndroid_url\x18\x06 \x01(\t\x12\x0f\n\x07web_url\x18\x07 \x01(\t\x12\x14\n\x0c\x66\x61llback_url\x18\x08 \x01(\t\x12\x12\n\nhuawei_url\x18\t \x01(\t\x12\x12\n\namazon_url\x18\n \x01(\t\x12\x13\n\x0bwindows_url\x18\x0b \x01(\t\x12\x11\n\tmacos_url\x18\x0c \x01(\t\x12\x10\n\x08\x61pp_name\x18\r \x01(\t\x12\x14\n\x0c\x61pp_icon_url\x18\x0e \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x0f \x01(\t\x12\x11\n\tis_active\x18\x10 \x01(\x08\x12\x14\n\x0ctotal_clicks\x18\x11 \x01(\x03\x12.\n\ncreated_at\x18\x12 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x13 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"2\n\x10ListLinksRequest\x12\x0c\n\x04page\x18\x01 \x01(\x05\x12\x10\n\x08per_page\x18\x02 \x01(\x05\"a\n\x11ListLinksResponse\x12\x1d\n\x05links\x18\x01 \x03(\x0b\x32\x0e.links.v1.Link\x12\r\n\x05total\x18\x02 \x01(\x05\x12\x0c\n\x04page\x18\x03 \x01(\x05\x12\x10\n\x08per_page\x18\x04 \x01(\x05\"\x8a\x02\n\x11\x43reateLinkRequest\x12\x0c\n\x04slug\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0f\n\x07ios_url\x18\x03 \x01(\t\x12\x13\n\x0b\x61ndroid_url\x18\x04 \x01(\t\x12\x0f\n\x07web_url\x18\x05 \x01(\t\x12\x14\n\x0c\x66\x61llback_url\x18\x06 \x01(\t\x12\x12\n\nhuawei_url\x18\x07 \x01(\t\x12\x12\n\namazon_url\x18\x08 \x01(\t\x12\x13\n\x0bwindows_url\x18\t \x01(\t\x12\x11\n\tmacos_url\x18\n \x01(\t\x12\x10\n\x08\x61pp_name\x18\x0b \x01(\t\x12\x14\n\x0c\x61pp_icon_url\x18\x0c \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\r \x01(\t\"\x1c\n\x0eGetLinkRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\x99\x02\n\x11UpdateLinkRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\x04slug\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05title\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x14\n\x07ios_url\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x18\n\x0b\x61ndroid_url\x18\x05 \x01(\tH\x03\x88\x01\x01\x12\x14\n\x07web_url\x18\x06 \x01(\tH\x04\x88\x01\x01\x12\x19\n\x0c\x66\x61llback_url\x18\x07 \x01(\tH\x05\x88\x01\x01\x12\x16\n\tis_active\x18\x08 \x01(\x08H\x06\x88\x01\x01\x42\x07\n\x05_slugB\x08\n\x06_titleB\n\n\x08_ios_urlB\x0e\n\x0c_android_urlB\n\n\x08_web_urlB\x0f\n\r_fallback_urlB\x0c\n\n_is_active\"\x1f\n\x11\x44\x65leteLinkRequest\x12\n\n\x02id\x18\x01 \x01(\t\"6\n\x12\x44\x65leteLinkResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\" \n\x10\x43heckSlugRequest\x12\x0c\n\x04slug\x18\x01 \x01(\t\"4\n\x11\x43heckSlugResponse\x12\x11\n\tavailable\x18\x01 \x01(\x08\x12\x0c\n\x04slug\x18\x02 \x01(\t2\x8d\x03\n\x0bLinkService\x12\x44\n\tListLinks\x12\x1a.links.v1.ListLinksRequest\x1a\x1b.links.v1.ListLinksResponse\x12\x39\n\nCreateLink\x12\x1b.links.v1.CreateLinkRequest\x1a\x0e.links.v1.Link\x12\x33\n\x07GetLink\x12\x18.links.v1.GetLinkRequest\x1a\x0e.links.v1.Link\x12\x39\n\nUpdateLink\x12\x1b.links.v1.UpdateLinkRequest\x1a\x0e.links.v1.Link\x12G\n\nDeleteLink\x12\x1b.links.v1.DeleteLinkRequest\x1a\x1c.links.v1.DeleteLinkResponse\x12\x44\n\tCheckSlug\x12\x1a.links.v1.CheckSlugRequest\x1a\x1b.links.v1.CheckSlugResponseB1Z/github.com/gosms-ge/go2-sdk/go/links/v1;linksv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'links.v1.links_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/gosms-ge/go2-sdk/go/links/v1;linksv1'
  _globals['_LINK']._serialized_start=68
  _globals['_LINK']._serialized_end=487
  _globals['_LISTLINKSREQUEST']._serialized_start=489
  _globals['_LISTLINKSREQUEST']._serialized_end=539
  _globals['_LISTLINKSRESPONSE']._serialized_start=541
  _globals['_LISTLINKSRESPONSE']._serialized_end=638
  _globals['_CREATELINKREQUEST']._serialized_start=641
  _globals['_CREATELINKREQUEST']._serialized_end=907
  _globals['_GETLINKREQUEST']._serialized_start=909
  _globals['_GETLINKREQUEST']._serialized_end=937
  _globals['_UPDATELINKREQUEST']._serialized_start=940
  _globals['_UPDATELINKREQUEST']._serialized_end=1221
  _globals['_DELETELINKREQUEST']._serialized_start=1223
  _globals['_DELETELINKREQUEST']._serialized_end=1254
  _globals['_DELETELINKRESPONSE']._serialized_start=1256
  _globals['_DELETELINKRESPONSE']._serialized_end=1310
  _globals['_CHECKSLUGREQUEST']._serialized_start=1312
  _globals['_CHECKSLUGREQUEST']._serialized_end=1344
  _globals['_CHECKSLUGRESPONSE']._serialized_start=1346
  _globals['_CHECKSLUGRESPONSE']._serialized_end=1398
  _globals['_LINKSERVICE']._serialized_start=1401
  _globals['_LINKSERVICE']._serialized_end=1798
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Campaign(_message.Message):
    __slots__ = ("id", "user_id", "name", "description", "destination_url", "pass_recipient_id", "recipient_param_name", "total_recipients", "total_clicks", "unique_clicks", "status", "created_at", "updated_at", "expires_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    DESTINATION_URL_FIELD_NUMBER: _ClassVar[int]
    PASS_RECIPIENT_ID_FIELD_NUMBER: _ClassVar[int]
    RECIPIENT_PARAM_NAME_FIELD_NUMBER: _ClassVar[int]
    TOTAL_RECIPIENTS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_CLICKS_FIELD_NUMBER: _ClassVar[int]
    UNIQUE_CLICKS_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    user_id: str
    name: str
    description: str
    destination_url: str
    pass_recipient_id: bool
    recipient_param_name: str
    total_recipients: int
    total_clicks: int
    unique_clicks: int
    status: str
    created_at: str
    updated_at: str
    expires_at: str
    def __init__(self, id: _Optional[str] = ..., user_id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., destination_url: _Optional[str] = ..., pass_recipient_id: bool = ..., recipient_param_name: _Optional[str] = ..., total_recipients: _Optional[int] = ..., total_clicks: _Optional[int] = ..., unique_clicks: _Optional[int] = ..., status: _Optional[str] = ..., created_at: _Optional[str] = ..., updated_at: _Optional[str] = ..., expires_at: _Optional[str] = ...) -> None: ...

class CampaignLink(_message.Message):
    __slots__ = ("id", "campaign_id", "slug", "recipient_id", "recipient_name", "recipient_metadata", "clicked", "first_clicked_at", "last_clicked_at", "click_count", "first_click_platform", "first_click_country", "first_click_city", "created_at", "short_url")
    class RecipientMetadataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    CAMPAIGN_ID_FIELD_NUMBER: _ClassVar[int]
    SLUG_FIELD_NUMBER: _ClassVar[int]
    RECIPIENT_ID_FIELD_NUMBER: _ClassVar[int]
    RECIPIENT_NAME_FIELD_NUMBER: _ClassVar[int]
    RECIPIENT_METADATA_FIELD_NUMBER: _ClassVar[int]
    CLICKED_FIELD_NUMBER: _ClassVar[int]
    FIRST_CLICKED_AT_FIELD_NUMBER: _ClassVar[int]
    LAST_CLICKED_AT_FIELD_NUMBER: _ClassVar[int]
    CLICK_COUNT_FIELD_NUMBER: _ClassVar[int]
    FIRST_CLICK_PLATFORM_FIELD_NUMBER: _ClassVar[int]
    FIRST_CLICK_COUNTRY_FIELD_NUMBER: _ClassVar[int]
    FIRST_CLICK_CITY_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    SHORT_URL_FIELD_NUMBER: _ClassVar[int]
    id: str
    campaign_id: str
    slug: str
    recipient_id: str
    recipient_name: str
    recipient_metadata: _containers.ScalarMap[str, str]
    clicked: bool
    first_clicked_at: str
    last_clicked_at: str
    click_count: int
    first_click_platform: str
    first_click_country: str
    first_click_city: str
    created_at: str
    short_url: str
    def __init__(self, id: _Optional[str] = ..., campaign_id: _Optional[str] = ..., slug: _Optional[str] = ..., recipient_id: _Optional[str] = ..., recipient_name: _Optional[str] = ..., recipient_metadata: _Optional[_Mapping[str, str]] = ..., clicked: bool = ..., first_clicked_at: _Optional[str] = ..., last_clicked_at: _Optional[str] = ..., click_count: _Optional[int] = ..., first_click_platform: _Optional[str] = ..., first_click_country: _Optional[str] = ..., first_click_city: _Optional[str] = ..., created_at: _Optional[str] = ..., short_url: _Optional[str] = ...) -> None: ...

class Recipient(_message.Message):
    __slots__ = ("id", "name", "metadata")
    class MetadataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    metadata: _containers.ScalarMap[str, str]
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., metadata: _Optional[_Mapping[str, str]] = ...) -> None: ...

class ListCampaignsRequest(_message.Message):
    __slots__ = ("limit", "offset", "status", "search")
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    SEARCH_FIELD_NUMBER: _ClassVar[int]
    limit: int
    offset: int
    status: str
    search: str
    def __init__(self, limit: _Optional[int] = ..., offset: _Optional[int] = ..., status: _Optional[str] = ..., search: _Optional[str] = ...) -> None: ...

class ListCampaignsResponse(_message.Message):
    __slots__ = ("campaigns", "total")
    CAMPAIGNS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    campaigns: _containers.RepeatedCompositeFieldContainer[Campaign]
    total: int
    def __init__(self, campaigns: _Optional[_Iterable[_Union[Campaign, _Mapping]]] = ..., total: _Optional[int] = ...) -> None: ...

class CreateCampaignRequest(_message.Message):
    __slots__ = ("name", "description", "destination_url", "pass_recipient_id", "recipient_param_name", "expires_at")
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    DESTINATION_URL_FIELD_NUMBER: _ClassVar[int]
    PASS_RECIPIENT_ID_FIELD_NUMBER: _ClassVar[int]
    RECIPIENT_PARAM_NAME_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    name: str
    description: str
    destination_url: str
    pass_recipient_id: bool
    recipient_param_name: str
    expires_at: str
    def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ..., destination_url: _Optional[str] = ..., pass_recipient_id: bool = ..., recipient_param_name: _Optional[str] = ..., expires_at: _Optional[str] = ...) -> None: ...

class GetCampaignRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class UpdateCampaignRequest(_message.Message):
    __slots__ = ("id", "name", "description", "destination_url", "pass_recipient_id", "recipient_param_name", "status", "expires_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    DESTINATION_URL_FIELD_NUMBER: _ClassVar[int]
    PASS_RECIPIENT_ID_FIELD_NUMBER: _ClassVar[int]
    RECIPIENT_PARAM_NAME_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: str
    destination_url: str
    pass_recipient_id: bool
    recipient_param_name: str
    status: str
    expires_at: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., destination_url: _Optional[str] = ..., pass_recipient_id: bool = ..., recipient_param_name: _Optional[str] = ..., status: _Optional[str] = ..., expires_at: _Optional[str] = ...) -> None: ...

class DeleteCampaignRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeleteCampaignResponse(_message.Message):
    __slots__ = ("success",)
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: bool = ...) -> None: ...

class GenerateLinksRequest(_message.Message):
    __slots__ = ("campaign_id", "recipients")
    CAMPAIGN_ID_FIELD_NUMBER: _ClassVar[int]
    RECIPIENTS_FIELD_NUMBER: _ClassVar[int]
    campaign_id: str
    recipients: _containers.RepeatedCompositeFieldContainer[Recipient]
    def __init__(self, campaign_id: _Optional[str] = ..., recipients: _Optional[_Iterable[_Union[Recipient, _Mapping]]] = ...) -> None: ...

class GenerateLinksResponse(_message.Message):
    __slots__ = ("campaign_id", "links_created", "sample_links")
    CAMPAIGN_ID_FIELD_NUMBER: _ClassVar[int]
    LINKS_CREATED_FIELD_NUMBER: _ClassVar[int]
    SAMPLE_LINKS_FIELD_NUMBER: _ClassVar[int]
    campaign_id: str
    links_created: int
    sample_links: _containers.RepeatedCompositeFieldContainer[CampaignLink]
    def __init__(self, campaign_id: _Optional[str] = ..., links_created: _Optional[int] = ..., sample_links: _Optional[_Iterable[_Union[CampaignLink, _Mapping]]] = ...) -> None: ...

class ListCampaignLinksRequest(_message.Message):
    __slots__ = ("campaign_id", "limit", "offset", "clicked_only", "search")
    CAMPAIGN_ID_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    CLICKED_ONLY_FIELD_NUMBER: _ClassVar[int]
    SEARCH_FIELD_NUMBER: _ClassVar[int]
    campaign_id: str
    limit: int
    offset: int
    clicked_only: bool
    search: str
    def __init__(self, campaign_id: _Optional[str] = ..., limit: _Optional[int] = ..., offset: _Optional[int] = ..., clicked_only: bool = ..., search: _Optional[str] = ...) -> None: ...

class ListCampaignLinksResponse(_message.Message):
    __slots__ = ("links", "total")
    LINKS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    links: _containers.RepeatedCompositeFieldContainer[CampaignLink]
    total: int
    def __init__(self, links: _Optional[_Iterable[_Union[CampaignLink, _Mapping]]] = ..., total: _Optional[int] = ...) -> None: ...

class GetCampaignStatsRequest(_message.Message):
    __slots__ = ("campaign_id",)
    CAMPAIGN_ID_FIELD_NUMBER: _ClassVar[int]
    campaign_id: str
    def __init__(self, campaign_id: _Optional[str] = ...) -> None: ...

class CampaignStats(_message.Message):
    __slots__ = ("campaign_id", "total_recipients", "total_clicks", "unique_clicks", "click_rate", "clicks_by_platform", "clicks_by_country", "clicks_by_day")
    class ClicksByPlatformEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: int
        def __init__(self, key: _Optional[str] = ..., value: _Optional[int] = ...) -> None: ...
    class ClicksByCountryEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: int
        def __init__(self, key: _Optional[str] = ..., value: _Optional[int] = ...) -> None: ...
    class ClicksByDayEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: int
        def __init__(self, key: _Optional[str] = ..., value: _Optional[int] = ...) -> None: ...
    CAMPAIGN_ID_FIELD_NUMBER: _ClassVar[int]
    TOTAL_RECIPIENTS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_CLICKS_FIELD_NUMBER: _ClassVar[int]
    UNIQUE_CLICKS_FIELD_NUMBER: _ClassVar[int]
    CLICK_RATE_FIELD_NUMBER: _ClassVar[int]
    CLICKS_BY_PLATFORM_FIELD_NUMBER: _ClassVar[int]
    CLICKS_BY_COUNTRY_FIELD_NUMBER: _ClassVar[int]
    CLICKS_BY_DAY_FIELD_NUMBER: _ClassVar[int]
    campaign_id: str
    total_recipients: int
    total_clicks: int
    unique_clicks: int
    click_rate: float
    clicks_by_platform: _containers.ScalarMap[str, int]
    clicks_by_country: _containers.ScalarMap[str, int]
    clicks_by_day: _containers.ScalarMap[str, int]
    def __init__(self, campaign_id: _Optional[str] = ..., total_recipients: _Optional[int] = ..., total_clicks: _Optional[int] = ..., unique_clicks: _Optional[int] = ..., click_rate: _Optional[float] = ..., clicks_by_platform: _Optional[_Mapping[str, int]] = ..., clicks_by_country: _Optional[_Mapping[str, int]] = ..., clicks_by_day: _Optional[_Mapping[str, int]] = ...) -> None: ...

class ExportLinksRequest(_message.Message):
    __slots__ = ("campaign_id", "format")
    CAMPAIGN_ID_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    campaign_id: str
    format: str
    def __init__(self, campaign_id: _Optional[str] = ..., format: _Optional[str] = ...) -> None: ...

class ExportLinksResponse(_message.Message):
    __slots__ = ("links",)
    LINKS_FIELD_NUMBER: _ClassVar[int]
    links: _containers.RepeatedCompositeFieldContainer[CampaignLink]
    def __init__(self, links: _Optional[_Iterable[_Union[CampaignLink, _Mapping]]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from campaigns.v1 import campaigns_pb2 as campaigns_dot_v1_dot_campaigns__pb2

GRPC_GENERATED_VERSION = '1.78.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in campaigns/v1/campaigns_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class CampaignServiceStub(object):
    """CampaignService handles SMS/Email marketing campaigns with bulk trackable links
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListCampaigns = channel.unary_unary(
                '/campaigns.v1.CampaignService/ListCampaigns',
                request_serializer=campaigns_dot_v1_dot_campaigns__pb2.ListCampaignsRequest.SerializeToString,
                response_deserializer=campaigns_dot_v1_dot_campaigns__pb2.ListCampaignsResponse.FromString,
                _registered_method=True)
        self.CreateCampaign = channel.unary_unary(
                '/campaigns.v1.CampaignService/CreateCampaign',
                request_serializer=campaigns_dot_v1_dot_campaigns__pb2.CreateCampaignRequest.SerializeToString,
                response_deserializer=campaigns_dot_v1_dot_campaigns__pb2.Campaign.FromString,
                _registered_method=True)
        self.GetCampaign = channel.unary_unary(
                '/campaigns.v1.CampaignService/GetCampaign',
                request_serializer=campaigns_dot_v1_dot_campaigns__pb2.GetCampaignRequest.SerializeToString,
                response_deserializer=campaigns_dot_v1_dot_campaigns__pb2.Campaign.FromString,
                _registered_method=True)
        self.UpdateCampaign = channel.unary_unary(
                '/campaigns.v1.CampaignService/UpdateCampaign',
                request_serializer=campaigns_dot_v1_dot_campaigns__pb2.UpdateCampaignRequest.SerializeToString,
                response_deserializer=campaigns_dot_v1_dot_campaigns__pb2.Campaign.FromString,
                _registered_method=True)
        self.DeleteCampaign = channel.unary_unary(
                '/campaigns.v1.CampaignService/DeleteCampaign',
                request_serializer=campaigns_dot_v1_dot_campaigns__pb2.DeleteCampaignRequest.SerializeToString,
                response_deserializer=campaigns_dot_v1_dot_campaigns__pb2.DeleteCampaignResponse.FromString,
                _registered_method=True)
        self.GenerateLinks = channel.unary_unary(
                '/campaigns.v1.CampaignService/GenerateLinks',
                request_serializer=campaigns_dot_v1_dot_campaigns__pb2.GenerateLinksRequest.SerializeToString,
                response_deserializer=campaigns_dot_v1_dot_campaigns__pb2.GenerateLinksResponse.FromString,
                _registered_method=True)
        self.ListCampaignLinks = channel.unary_unary(
                '/campaigns.v1.CampaignService/ListCampaignLinks',
                request_serializer=campaigns_dot_v1_dot_campaigns__pb2.ListCampaignLinksRequest.SerializeToString,
                response_deserializer=campaigns_dot_v1_dot_campaigns__pb2.ListCampaignLinksResponse.FromString,
                _registered_method=True)
        self.GetCampaignStats = channel.unary_unary(
                '/campaigns.v1.CampaignService/GetCampaignStats',
                request_serializer=campaigns_dot_v1_dot_campaigns__pb2.GetCampaignStatsRequest.SerializeToString,
                response_deserializer=campaigns_dot_v1_dot_campaigns__pb2.CampaignStats.FromString,
                _registered_method=True)
        self.ExportLinks = channel.unary_unary(
                '/campaigns.v1.CampaignService/ExportLinks',
                request_serializer=campaigns_dot_v1_dot_campaigns__pb2.ExportLinksRequest.SerializeToString,
                response_deserializer=campaigns_dot_v1_dot_campaigns__pb2.ExportLinksResponse.FromString,
                _registered_method=True)


class CampaignServiceServicer(object):
    """CampaignService handles SMS/Email marketing campaigns with bulk trackable links
    """

    def ListCampaigns(self, request, context):
        """List all campaigns
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateCampaign(self, request, context):
        """Create a new campaign
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCampaign(self, request, context):
        """Get a campaign by ID
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateCampaign(self, request, context):
        """Update a campaign
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteCampaign(self, request, context):
        """Delete a campaign
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GenerateLinks(self, request, context):
        """Generate links for campaign recipients in bulk
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListCampaignLinks(self, request, context):
        """List campaign links with pagination
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCampaignStats(self, request, context):
        """Get campaign statistics
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExportLinks(self, request, context):
        """Export all campaign links
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CampaignServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListCampaigns': grpc.unary_unary_rpc_method_handler(
                    servicer.ListCampaigns,
                    request_deserializer=campaigns_dot_v1_dot_campaigns__pb2.ListCampaignsRequest.FromString,
                    response_serializer=campaigns_dot_v1_dot_campaigns__pb2.ListCampaignsResponse.SerializeToString,
            ),
            'CreateCampaign': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateCampaign,
                    request_deserializer=campaigns_dot_v1_dot_campaigns__pb2.CreateCampaignRequest.FromString,
                    response_serializer=campaigns_dot_v1_dot_campaigns__pb2.Campaign.SerializeToString,
            ),
            'GetCampaign': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCampaign,
                    request_deserializer=campaigns_dot_v1_dot_campaigns__pb2.GetCampaignRequest.FromString,
                    response_serializer=campaigns_dot_v1_dot_campaigns__pb2.Campaign.SerializeToString,
            ),
            'UpdateCampaign': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateCampaign,
                    request_deserializer=campaigns_dot_v1_dot_campaigns__pb2.UpdateCampaignRequest.FromString,
                    response_serializer=campaigns_dot_v1_dot_campaigns__pb2.Campaign.SerializeToString,
            ),
            'DeleteCampaign': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteCampaign,
                    request_deserializer=campaigns_dot_v1_dot_campaigns__pb2.DeleteCampaignRequest.FromString,
                    response_serializer=campaigns_dot_v1_dot_campaigns__pb2.DeleteCampaignResponse.SerializeToString,
            ),
            'GenerateLinks': grpc.unary_unary_rpc_method_handler(
                    servicer.GenerateLinks,
                    request_deserializer=campaigns_dot_v1_dot_campaigns__pb2.GenerateLinksRequest.FromString,
                    response_serializer=campaigns_dot_v1_dot_campaigns__pb2.GenerateLinksResponse.SerializeToString,
            ),
            'ListCampaignLinks': grpc.unary_unary_rpc_method_handler(
                    servicer.ListCampaignLinks,
                    request_deserializer=campaigns_dot_v1_dot_campaigns__pb2.ListCampaignLinksRequest.FromString,
                    response_serializer=campaigns_dot_v1_dot_campaigns__pb2.ListCampaignLinksResponse.SerializeToString,
            ),
            'GetCampaignStats': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCampaignStats,
                    request_deserializer=campaigns_dot_v1_dot_campaigns__pb2.GetCampaignStatsRequest.FromString,
                    response_serializer=campaigns_dot_v1_dot_campaigns__pb2.CampaignStats.SerializeToString,
            ),
            'ExportLinks': grpc.unary_unary_rpc_method_handler(
                    servicer.ExportLinks,
                    request_deserializer=campaigns_dot_v1_dot_campaigns__pb2.ExportLinksRequest.FromString,
                    response_serializer=campaigns_dot_v1_dot_campaigns__pb2.ExportLinksResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'campaigns.v1.CampaignService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('campaigns.v1.CampaignService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class CampaignService(object):
    """CampaignService handles SMS/Email marketing campaigns with bulk trackable links
    """

    @staticmethod
    def ListCampaigns(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/campaigns.v1.CampaignService/ListCampaigns',
            campaigns_dot_v1_dot_campaigns__pb2.ListCampaignsRequest.SerializeToString,
            campaigns_dot_v1_dot_campaigns__pb2.ListCampaignsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateCampaign(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/campaigns.v1.CampaignService/CreateCampaign',
            campaigns_dot_v1_dot_campaigns__pb2.CreateCampaignRequest.SerializeToString,
            campaigns_dot_v1_dot_campaigns__pb2.Campaign.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetCampaign(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/campaigns.v1.CampaignService/GetCampaign',
            campaigns_dot_v1_dot_campaigns__pb2.GetCampaignRequest.SerializeToString,
            campaigns_dot_v1_dot_campaigns__pb2.Campaign.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateCampaign(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/campaigns.v1.CampaignService/UpdateCampaign',
            campaigns_dot_v1_dot_campaigns__pb2.UpdateCampaignRequest.SerializeToString,
            campaigns_dot_v1_dot_campaigns__pb2.Campaign.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteCampaign(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/campaigns.v1.CampaignService/DeleteCampaign',
            campaigns_dot_v1_dot_campaigns__pb2.DeleteCampaignRequest.SerializeToString,
            campaigns_dot_v1_dot_campaigns__pb2.DeleteCampaignResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GenerateLinks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/campaigns.v1.CampaignService/GenerateLinks',
            campaigns_dot_v1_dot_campaigns__pb2.GenerateLinksRequest.SerializeToString,
            campaigns_dot_v1_dot_campaigns__pb2.GenerateLinksResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListCampaignLinks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/campaigns.v1.CampaignService/ListCampaignLinks',
            campaigns_dot_v1_dot_campaigns__pb2.ListCampaignLinksRequest.SerializeToString,
            campaigns_dot_v1_dot_campaigns__pb2.ListCampaignLinksResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetCampaignStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/campaigns.v1.CampaignService/GetCampaignStats',
            campaigns_dot_v1_dot_campaigns__pb2.GetCampaignStatsRequest.SerializeToString,
            campaigns_dot_v1_dot_campaigns__pb2.CampaignStats.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ExportLinks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/campaigns.v1.CampaignService/ExportLinks',
            campaigns_dot_v1_dot_campaigns__pb2.ExportLinksRequest.SerializeToString,
            campaigns_dot_v1_dot_campaigns__pb2.ExportLinksResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: qr/v1/qr.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'qr/v1/qr.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eqr/v1/qr.proto\x12\x05qr.v1\"\x88\x01\n\x11GenerateQRRequest\x12\x0f\n\x07link_id\x18\x01 \x01(\t\x12\x0c\n\x04size\x18\x02 \x01(\x05\x12\x0e\n\x06\x66ormat\x18\x03 \x01(\t\x12\x18\n\x10\x66oreground_color\x18\x04 \x01(\t\x12\x18\n\x10\x62\x61\x63kground_color\x18\x05 \x01(\t\x12\x10\n\x08logo_url\x18\x06 \x01(\t\"?\n\x12GenerateQRResponse\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0c\n\x04size\x18\x02 \x01(\x05\x12\x0e\n\x06\x66ormat\x18\x03 \x01(\t2N\n\tQRService\x12\x41\n\nGenerateQR\x12\x18.qr.v1.GenerateQRRequest\x1a\x19.qr.v1.GenerateQRResponseB+Z)github.com/gosms-ge/go2-sdk/go/qr/v1;qrv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qr.v1.qr_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/gosms-ge/go2-sdk/go/qr/v1;qrv1'
  _globals['_GENERATEQRREQUEST']._serialized_start=26
  _globals['_GENERATEQRREQUEST']._serialized_end=162
  _globals['_GENERATEQRRESPONSE']._serialized_start=164
  _globals['_GENERATEQRRESPONSE']._serialized_end=227
  _globals['_QRSERVICE']._serialized_start=229
  _globals['_QRSERVICE']._serialized_end=307
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: analytics/v1/analytics.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'analytics/v1/analytics.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x61nalytics/v1/analytics.proto\x12\x0c\x61nalytics.v1\"2\n\x0fGetStatsRequest\x12\x0f\n\x07link_id\x18\x01 \x01(\t\x12\x0e\n\x06period\x18\x02 \x01(\t\"\xfc\x01\n\x10GetStatsResponse\x12\x14\n\x0ctotal_clicks\x18\x01 \x01(\x03\x12\x15\n\runique_clicks\x18\x02 \x01(\x03\x12\x12\n\nios_clicks\x18\x03 \x01(\x03\x12\x16\n\x0e\x61ndroid_clicks\x18\x04 \x01(\x03\x12\x12\n\nweb_clicks\x18\x05 \x01(\x03\x12\x14\n\x0cother_clicks\x18\x06 \x01(\x03\x12\x31\n\rtop_countries\x18\x07 \x03(\x0b\x32\x1a.analytics.v1.CountryStats\x12\x32\n\rtop_referrers\x18\x08 \x03(\x0b\x32\x1b.analytics.v1.ReferrerStats\"7\n\x14GetTimeseriesRequest\x12\x0f\n\x07link_id\x18\x01 \x01(\t\x12\x0e\n\x06period\x18\x02 \x01(\t\"F\n\x15GetTimeseriesResponse\x12-\n\x06points\x18\x01 \x03(\x0b\x32\x1d.analytics.v1.TimeseriesPoint\"F\n\x0fTimeseriesPoint\x12\x0c\n\x04\x64\x61te\x18\x01 \x01(\t\x12\x0e\n\x06\x63licks\x18\x02 \x01(\x03\x12\x15\n\runique_clicks\x18\x03 \x01(\x03\"6\n\x13GetPlatformsRequest\x12\x0f\n\x07link_id\x18\x01 \x01(\t\x12\x0e\n\x06period\x18\x02 \x01(\t\"F\n\x14GetPlatformsResponse\x12.\n\tplatforms\x18\x01 \x03(\x0b\x32\x1b.analytics.v1.PlatformStats\"E\n\rPlatformStats\x12\x10\n\x08platform\x18\x01 \x01(\t\x12\x0e\n\x06\x63licks\x18\x02 \x01(\x03\x12\x12\n\npercentage\x18\x03 \x01(\x01\"E\n\x13GetCountriesRequest\x12\x0f\n\x07link_id\x18\x01 \x01(\t\x12\x0e\n\x06period\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x05\"E\n\x14GetCountriesResponse\x12-\n\tcountries\x18\x01 \x03(\x0b\x32\x1a.analytics.v1.CountryStats\"^\n\x0c\x43ountryStats\x12\x14\n\x0c\x63ountry_code\x18\x01 \x01(\t\x12\x14\n\x0c\x63ountry_name\x18\x02 \x01(\t\x12\x0e\n\x06\x63licks\x18\x03 \x01(\x03\x12\x12\n\npercentage\x18\x04 \x01(\x01\"E\n\x13GetReferrersRequest\x12\x0f\n\x07link_id\x18\x01 \x01(\t\x12\x0e\n\x06period\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x05\"F\n\x14GetReferrersResponse\x12.\n\treferrers\x18\x01 \x03(\x0b\x32\x1b.analytics.v1.ReferrerStats\"E\n\rReferrerStats\x12\x10\n\x08referrer\x18\x01 \x01(\t\x12\x0e\n\x06\x63licks\x18\x02 \x01(\x03\x12\x12\n\npercentage\x18\x03 \x01(\x01\x32\xbc\x03\n\x10\x41nalyticsService\x12I\n\x08GetStats\x12\x1d.analytics.v1.GetStatsRequest\x1a\x1e.analytics.v1.GetStatsResponse\x12X\n\rGetTimeseries\x12\".analytics.v1.GetTimeseriesRequest\x1a#.analytics.v1.GetTimeseriesResponse\x12U\n\x0cGetPlatforms\x12!.analytics.v1.GetPlatformsRequest\x1a\".analytics.v1.GetPlatformsResponse\x12U\n\x0cGetCountries\x12!.analytics.v1.GetCountriesRequest\x1a\".analytics.v1.GetCountriesResponse\x12U\n\x0cGetReferrers\x12!.analytics.v1.GetReferrersRequest\x1a\".analytics.v1.GetReferrersResponseB9Z7github.com/gosms-ge/go2-sdk/go/analytics/v1;analyticsv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'analytics.v1.analytics_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/gosms-ge/go2-sdk/go/analytics/v1;analyticsv1'
  _globals['_GETSTATSREQUEST']._serialized_start=46
  _globals['_GETSTATSREQUEST']._serialized_end=96
  _globals['_GETSTATSRESPONSE']._serialized_start=99
  _globals['_GETSTATSRESPONSE']._serialized_end=351
  _globals['_GETTIMESERIESREQUEST']._serialized_start=353
  _globals['_GETTIMESERIESREQUEST']._serialized_end=408
  _globals['_GETTIMESERIESRESPONSE']._serialized_start=410
  _globals['_GETTIMESERIESRESPONSE']._serialized_end=480
  _globals['_TIMESERIESPOINT']._serialized_start=482
  _globals['_TIMESERIESPOINT']._serialized_end=552
  _globals['_GETPLATFORMSREQUEST']._serialized_start=554
  _globals['_GETPLATFORMSREQUEST']._serialized_end=608
  _globals['_GETPLATFORMSRESPONSE']._serialized_start=610
  _globals['_GETPLATFORMSRESPONSE']._serialized_end=680
  _globals['_PLATFORMSTATS']._serialized_start=682
  _globals['_PLATFORMSTATS']._serialized_end=751
  _globals['_GETCOUNTRIESREQUEST']._serialized_start=753
  _globals['_GETCOUNTRIESREQUEST']._serialized_end=822
  _globals['_GETCOUNTRIESRESPONSE']._serialized_start=824
  _globals['_GETCOUNTRIESRESPONSE']._serialized_end=893
  _globals['_COUNTRYSTATS']._serialized_start=895
  _globals['_COUNTRYSTATS']._serialized_end=989
  _globals['_GETREFERRERSREQUEST']._serialized_start=991
  _globals['_GETREFERRERSREQUEST']._serialized_end=1060
  _globals['_GETREFERRERSRESPONSE']._serialized_start=1062
  _globals['_GETREFERRERSRESPONSE']._serialized_end=1132
  _globals['_REFERRERSTATS']._serialized_start=1134
  _globals['_REFERRERSTATS']._serialized_end=1203
  _globals['_ANALYTICSSERVICE']._serialized_start=1206
  _globals['_ANALYTICSSERVICE']._serialized_end=1650
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: integrations/v1/integrations.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'integrations/v1/integrations.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"integrations/v1/integrations.proto\x12\x0fintegrations.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\x88\x03\n\x0bIntegration\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12.\n\x04type\x18\x03 \x01(\x0e\x32 .integrations.v1.IntegrationType\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x32\n\x06\x63onfig\x18\x05 \x01(\x0b\x32\".integrations.v1.IntegrationConfig\x12\x0e\n\x06\x65vents\x18\x06 \x03(\t\x12\x11\n\tis_active\x18\x07 \x01(\x08\x12:\n\x11last_triggered_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x12\x15\n\rtrigger_count\x18\t \x01(\x05\x12.\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x14\n\x12_last_triggered_at\"p\n\x11IntegrationConfig\x12\x13\n\x0bwebhook_url\x18\x01 \x01(\t\x12\x0f\n\x07\x63hannel\x18\x02 \x01(\t\x12\x11\n\tbot_token\x18\x03 \x01(\t\x12\x0f\n\x07\x63hat_id\x18\x04 \x01(\t\x12\x11\n\twrite_key\x18\x05 \x01(\t\"\x19\n\x17ListIntegrationsRequest\"N\n\x18ListIntegrationsResponse\x12\x32\n\x0cintegrations\x18\x01 \x03(\x0b\x32\x1c.integrations.v1.Integration\"\x9c\x01\n\x18\x43reateIntegrationRequest\x12.\n\x04type\x18\x01 \x01(\x0e\x32 .integrations.v1.IntegrationType\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x32\n\x06\x63onfig\x18\x03 \x01(\x0b\x32\".integrations.v1.IntegrationConfig\x12\x0e\n\x06\x65vents\x18\x04 \x03(\t\"#\n\x15GetIntegrationRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\xbc\x01\n\x18UpdateIntegrationRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\x04name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x37\n\x06\x63onfig\x18\x03 \x01(\x0b\x32\".integrations.v1.IntegrationConfigH\x01\x88\x01\x01\x12\x0e\n\x06\x65vents\x18\x04 \x03(\t\x12\x16\n\tis_active\x18\x05 \x01(\x08H\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_configB\x0c\n\n_is_active\"&\n\x18\x44\x65leteIntegrationRequest\x12\n\n\x02id\x18\x01 \x01(\t\",\n\x19\x44\x65leteIntegrationResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"$\n\x16TestIntegrationRequest\x12\n\n\x02id\x18\x01 \x01(\t\";\n\x17TestIntegrationResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"\x1c\n\x1aGetIntegrationTypesRequest\"b\n\x1bGetIntegrationTypesResponse\x12\x33\n\x05types\x18\x01 \x03(\x0b\x32$.integrations.v1.IntegrationTypeInfo\x12\x0e\n\x06\x65vents\x18\x02 \x03(\t\"\xbe\x01\n\x13IntegrationTypeInfo\x12.\n\x04type\x18\x01 \x01(\x0e\x32 .integrations.v1.IntegrationType\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0c\n\x04icon\x18\x04 \x01(\t\x12\x11\n\tavailable\x18\x05 \x01(\x08\x12\x33\n\rconfig_fields\x18\x06 \x03(\x0b\x32\x1c.integrations.v1.ConfigField\"x\n\x0b\x43onfigField\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x01(\t\x12\x12\n\nfield_type\x18\x03 \x01(\t\x12\x10\n\x08required\x18\x04 \x01(\x08\x12\x13\n\x0bplaceholder\x18\x05 \x01(\t\x12\x11\n\thelp_text\x18\x06 \x01(\t*\xc7\x01\n\x0fIntegrationType\x12 \n\x1cINTEGRATION_TYPE_UNSPECIFIED\x10\x00\x12\x1a\n\x16INTEGRATION_TYPE_SLACK\x10\x01\x12\x1c\n\x18INTEGRATION_TYPE_DISCORD\x10\x02\x12\x1d\n\x19INTEGRATION_TYPE_TELEGRAM\x10\x03\x12\x1c\n\x18INTEGRATION_TYPE_SEGMENT\x10\x04\x12\x1b\n\x17INTEGRATION_TYPE_ZAPIER\x10\x05\x32\xd5\x05\n\x12IntegrationService\x12g\n\x10ListIntegrations\x12(.integrations.v1.ListIntegrationsRequest\x1a).integrations.v1.ListIntegrationsResponse\x12\\\n\x11\x43reateIntegration\x12).integrations.v1.CreateIntegrationRequest\x1a\x1c.integrations.v1.Integration\x12V\n\x0eGetIntegration\x12&.integrations.v1.GetIntegrationRequest\x1a\x1c.integrations.v1.Integration\x12\\\n\x11UpdateIntegration\x12).integrations.v1.UpdateIntegrationRequest\x1a\x1c.integrations.v1.Integration\x12j\n\x11\x44\x65leteIntegration\x12).integrations.v1.DeleteIntegrationRequest\x1a*.integrations.v1.DeleteIntegrationResponse\x12\x64\n\x0fTestIntegration\x12\'.integrations.v1.TestIntegrationRequest\x1a(.integrations.v1.TestIntegrationResponse\x12p\n\x13GetIntegrationTypes\x12+.integrations.v1.GetIntegrationTypesRequest\x1a,.integrations.v1.GetIntegrationTypesResponseBCZAgithub.com/go2-link/backend/pkg/pb/integrations/v1;integrationsv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'integrations.v1.integrations_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/go2-link/backend/pkg/pb/integrations/v1;integrationsv1'
  _globals['_INTEGRATIONTYPE']._serialized_start=1722
  _globals['_INTEGRATIONTYPE']._serialized_end=1921
  _globals['_INTEGRATION']._serialized_start=89
  _globals['_INTEGRATION']._serialized_end=481
  _globals['_INTEGRATIONCONFIG']._serialized_start=483
  _globals['_INTEGRATIONCONFIG']._serialized_end=595
  _globals['_LISTINTEGRATIONSREQUEST']._serialized_start=597
  _globals['_LISTINTEGRATIONSREQUEST']._serialized_end=622
  _globals['_LISTINTEGRATIONSRESPONSE']._serialized_start=624
  _globals['_LISTINTEGRATIONSRESPONSE']._serialized_end=702
  _globals['_CREATEINTEGRATIONREQUEST']._serialized_start=705
  _globals['_CREATEINTEGRATIONREQUEST']._serialized_end=861
  _globals['_GETINTEGRATIONREQUEST']._serialized_start=863
  _globals['_GETINTEGRATIONREQUEST']._serialized_end=898
  _globals['_UPDATEINTEGRATIONREQUEST']._serialized_start=901
  _globals['_UPDATEINTEGRATIONREQUEST']._serialized_end=1089
  _globals['_DELETEINTEGRATIONREQUEST']._serialized_start=1091
  _globals['_DELETEINTEGRATIONREQUEST']._serialized_end=1129
  _globals['_DELETEINTEGRATIONRESPONSE']._serialized_start=1131
  _globals['_DELETEINTEGRATIONRESPONSE']._serialized_end=1175
  _globals['_TESTINTEGRATIONREQUEST']._serialized_start=1177
  _globals['_TESTINTEGRATIONREQUEST']._serialized_end=1213
  _globals['_TESTINTEGRATIONRESPONSE']._serialized_start=1215
  _globals['_TESTINTEGRATIONRESPONSE']._serialized_end=1274
  _globals['_GETINTEGRATIONTYPESREQUEST']._serialized_start=1276
  _globals['_GETINTEGRATIONTYPESREQUEST']._serialized_end=1304
  _globals['_GETINTEGRATIONTYPESRESPONSE']._serialized_start=1306
  _globals['_GETINTEGRATIONTYPESRESPONSE']._serialized_end=1404
  _globals['_INTEGRATIONTYPEINFO']._serialized_start=1407
  _globals['_INTEGRATIONTYPEINFO']._serialized_end=1597
  _globals['_CONFIGFIELD']._serialized_start=1599
  _globals['_CONFIGFIELD']._serialized_end=1719
  _globals['_INTEGRATIONSERVICE']._serialized_start=1924
  _globals['_INTEGRATIONSERVICE']._serialized_end=2649
# @@protoc_insertion_point(module_scope)



"""Go2 gRPC API Client."""

from typing import List, Optional, Any, Dict
import grpc

from go2_sdk.errors import wrap_error

DEFAULT_ENDPOINT = "grpc.go2.ge:443"


class _AuthInterceptor(grpc.UnaryUnaryClientInterceptor):
    """Interceptor that adds API key to all requests."""

    def __init__(self, api_key: str):
        self._api_key = api_key

    def intercept_unary_unary(
        self,
        continuation: Any,
        client_call_details: grpc.ClientCallDetails,
        request: Any,
    ) -> Any:
        metadata = list(client_call_details.metadata or [])
        metadata.append(("x-api-key", self._api_key))

        new_details = grpc.ClientCallDetails(
            method=client_call_details.method,
            timeout=client_call_details.timeout,
            metadata=metadata,
            credentials=client_call_details.credentials,
            wait_for_ready=client_call_details.wait_for_ready,
            compression=client_call_details.compression,
        )

        return continuation(new_details, request)


class IntegrationsService:
    """Service for managing integrations."""

    def __init__(self, stub: Any):
        self._stub = stub

    def list(self) -> List[Any]:
        """List all integrations."""
        from go2_sdk.gen.integrations.v1 import integrations_pb2

        try:
            response = self._stub.ListIntegrations(
                integrations_pb2.ListIntegrationsRequest()
            )
            return list(response.integrations)
        except grpc.RpcError as e:
            raise wrap_error(e)

    def create(
        self,
        type: Any,
        name: str,
        config: Any,
        events: List[str],
    ) -> Any:
        """Create a new integration."""
        from go2_sdk.gen.integrations.v1 import integrations_pb2

        try:
            return self._stub.CreateIntegration(
                integrations_pb2.CreateIntegrationRequest(
                    type=type,
                    name=name,
                    config=config,
                    events=events,
                )
            )
        except grpc.RpcError as e:
            raise wrap_error(e)

    def get(self, id: str) -> Any:
        """Get an integration by ID."""
        from go2_sdk.gen.integrations.v1 import integrations_pb2

        try:
            return self._stub.GetIntegration(
                integrations_pb2.GetIntegrationRequest(id=id)
            )
        except grpc.RpcError as e:
            raise wrap_error(e)

    def update(
        self,
        id: str,
        name: Optional[str] = None,
        config: Optional[Any] = None,
        events: Optional[List[str]] = None,
        is_active: Optional[bool] = None,
    ) -> Any:
        """Update an integration."""
        from go2_sdk.gen.integrations.v1 import integrations_pb2

        request = integrations_pb2.UpdateIntegrationRequest(id=id)
        if name is not None:
            request.name = name
        if config is not None:
            request.config.CopyFrom(config)
        if events is not None:
            request.events.extend(events)
        if is_active is not None:
            request.is_active = is_active

        try:
            return self._stub.UpdateIntegration(request)
        except grpc.RpcError as e:
            raise wrap_error(e)

    def delete(self, id: str) -> bool:
        """Delete an integration."""
        from go2_sdk.gen.integrations.v1 import integrations_pb2

        try:
            response = self._stub.DeleteIntegration(
                integrations_pb2.DeleteIntegrationRequest(id=id)
            )
            return response.success
        except grpc.RpcError as e:
            raise wrap_error(e)

    def test(self, id: str) -> Any:
        """Test an integration by sending a test notification."""
        from go2_sdk.gen.integrations.v1 import integrations_pb2

        try:
            return self._stub.TestIntegration(
                integrations_pb2.TestIntegrationRequest(id=id)
            )
        except grpc.RpcError as e:
            raise wrap_error(e)

    def get_types(self) -> Any:
        """Get available integration types and events."""
        from go2_sdk.gen.integrations.v1 import integrations_pb2

        try:
            return self._stub.GetIntegrationTypes(
                integrations_pb2.GetIntegrationTypesRequest()
            )
        except grpc.RpcError as e:
            raise wrap_error(e)


class LinksService:
    """Service for managing smart links."""

    def __init__(self, stub: Any):
        self._stub = stub

    def list(self, page: int = 1, per_page: int = 20) -> Any:
        """List all links."""
        from go2_sdk.gen.links.v1 import links_pb2

        try:
            return self._stub.ListLinks(
                links_pb2.ListLinksRequest(page=page, per_page=per_page)
            )
        except grpc.RpcError as e:
            raise wrap_error(e)

    def create(
        self,
        slug: str,
        title: Optional[str] = None,
        ios_url: Optional[str] = None,
        android_url: Optional[str] = None,
        web_url: Optional[str] = None,
        fallback_url: Optional[str] = None,
    ) -> Any:
        """Create a new smart link."""
        from go2_sdk.gen.links.v1 import links_pb2

        try:
            return self._stub.CreateLink(
                links_pb2.CreateLinkRequest(
                    slug=slug,
                    title=title or "",
                    ios_url=ios_url or "",
                    android_url=android_url or "",
                    web_url=web_url or "",
                    fallback_url=fallback_url or "",
                )
            )
        except grpc.RpcError as e:
            raise wrap_error(e)

    def get(self, id: str) -> Any:
        """Get a link by ID."""
        from go2_sdk.gen.links.v1 import links_pb2

        try:
            return self._stub.GetLink(links_pb2.GetLinkRequest(id=id))
        except grpc.RpcError as e:
            raise wrap_error(e)

    def update(
        self,
        id: str,
        title: Optional[str] = None,
        ios_url: Optional[str] = None,
        android_url: Optional[str] = None,
        web_url: Optional[str] = None,
        fallback_url: Optional[str] = None,
        is_active: Optional[bool] = None,
    ) -> Any:
        """Update a link."""
        from go2_sdk.gen.links.v1 import links_pb2

        request = links_pb2.UpdateLinkRequest(id=id)
        if title is not None:
            request.title = title
        if ios_url is not None:
            request.ios_url = ios_url
        if android_url is not None:
            request.android_url = android_url
        if web_url is not None:
            request.web_url = web_url
        if fallback_url is not None:
            request.fallback_url = fallback_url
        if is_active is not None:
            request.is_active = is_active

        try:
            return self._stub.UpdateLink(request)
        except grpc.RpcError as e:
            raise wrap_error(e)

    def delete(self, id: str) -> bool:
        """Delete a link."""
        from go2_sdk.gen.links.v1 import links_pb2

        try:
            response = self._stub.DeleteLink(links_pb2.DeleteLinkRequest(id=id))
            return response.success
        except grpc.RpcError as e:
            raise wrap_error(e)


class AnalyticsService:
    """Service for link analytics."""

    def __init__(self, stub: Any):
        self._stub = stub

    def get_stats(self, link_id: str, period: str = "30d") -> Any:
        """Get stats for a link."""
        from go2_sdk.gen.analytics.v1 import analytics_pb2

        try:
            return self._stub.GetStats(
                analytics_pb2.GetStatsRequest(link_id=link_id, period=period)
            )
        except grpc.RpcError as e:
            raise wrap_error(e)

    def get_timeseries(self, link_id: str, period: str = "30d") -> Any:
        """Get timeseries data for a link."""
        from go2_sdk.gen.analytics.v1 import analytics_pb2

        try:
            return self._stub.GetTimeseries(
                analytics_pb2.GetTimeseriesRequest(link_id=link_id, period=period)
            )
        except grpc.RpcError as e:
            raise wrap_error(e)

    def get_platforms(self, link_id: str, period: str = "30d") -> Any:
        """Get platform breakdown for a link."""
        from go2_sdk.gen.analytics.v1 import analytics_pb2

        try:
            return self._stub.GetPlatforms(
                analytics_pb2.GetPlatformsRequest(link_id=link_id, period=period)
            )
        except grpc.RpcError as e:
            raise wrap_error(e)

    def get_countries(self, link_id: str, period: str = "30d", limit: int = 10) -> Any:
        """Get country breakdown for a link."""
        from go2_sdk.gen.analytics.v1 import analytics_pb2

        try:
            return self._stub.GetCountries(
                analytics_pb2.GetCountriesRequest(
                    link_id=link_id, period=period, limit=limit
                )
            )
        except grpc.RpcError as e:
            raise wrap_error(e)

    def get_referrers(self, link_id: str, period: str = "30d", limit: int = 10) -> Any:
        """Get referrer breakdown for a link."""
        from go2_sdk.gen.analytics.v1 import analytics_pb2

        try:
            return self._stub.GetReferrers(
                analytics_pb2.GetReferrersRequest(
                    link_id=link_id, period=period, limit=limit
                )
            )
        except grpc.RpcError as e:
            raise wrap_error(e)


class DomainsService:
    """Service for managing custom domains."""

    def __init__(self, stub: Any):
        self._stub = stub

    def list(self) -> List[Any]:
        """List all custom domains."""
        from go2_sdk.gen.domains.v1 import domains_pb2

        try:
            response = self._stub.ListDomains(domains_pb2.ListDomainsRequest())
            return list(response.domains)
        except grpc.RpcError as e:
            raise wrap_error(e)

    def create(self, domain: str) -> Any:
        """Add a custom domain."""
        from go2_sdk.gen.domains.v1 import domains_pb2

        try:
            return self._stub.CreateDomain(
                domains_pb2.CreateDomainRequest(domain=domain)
            )
        except grpc.RpcError as e:
            raise wrap_error(e)

    def get(self, id: str) -> Any:
        """Get a domain by ID."""
        from go2_sdk.gen.domains.v1 import domains_pb2

        try:
            return self._stub.GetDomain(domains_pb2.GetDomainRequest(id=id))
        except grpc.RpcError as e:
            raise wrap_error(e)

    def delete(self, id: str) -> bool:
        """Delete a custom domain."""
        from go2_sdk.gen.domains.v1 import domains_pb2

        try:
            response = self._stub.DeleteDomain(
                domains_pb2.DeleteDomainRequest(id=id)
            )
            return response.success
        except grpc.RpcError as e:
            raise wrap_error(e)

    def verify(self, id: str) -> Any:
        """Verify a custom domain."""
        from go2_sdk.gen.domains.v1 import domains_pb2

        try:
            return self._stub.VerifyDomain(domains_pb2.VerifyDomainRequest(id=id))
        except grpc.RpcError as e:
            raise wrap_error(e)


class QRService:
    """Service for QR code generation."""

    def __init__(self, stub: Any):
        self._stub = stub

    def generate(
        self,
        link_id: str,
        size: int = 256,
        format: str = "png",
        foreground_color: str = "#000000",
        background_color: str = "#FFFFFF",
    ) -> Any:
        """Generate a QR code for a link."""
        from go2_sdk.gen.qr.v1 import qr_pb2

        try:
            return self._stub.GenerateQR(
                qr_pb2.GenerateQRRequest(
                    link_id=link_id,
                    size=size,
                    format=format,
                    foreground_color=foreground_color,
                    background_color=background_color,
                )
            )
        except grpc.RpcError as e:
            raise wrap_error(e)


class CampaignsService:
    """Service for managing marketing campaigns."""

    def __init__(self, stub: Any):
        self._stub = stub

    def list(self, page: int = 1, per_page: int = 20) -> Any:
        """List all campaigns."""
        from go2_sdk.gen.campaigns.v1 import campaigns_pb2

        try:
            return self._stub.ListCampaigns(
                campaigns_pb2.ListCampaignsRequest(page=page, per_page=per_page)
            )
        except grpc.RpcError as e:
            raise wrap_error(e)

    def create(
        self,
        name: str,
        base_link_id: str,
        type: str = "sms",
        utm_source: Optional[str] = None,
        utm_medium: Optional[str] = None,
        utm_campaign: Optional[str] = None,
    ) -> Any:
        """Create a new campaign."""
        from go2_sdk.gen.campaigns.v1 import campaigns_pb2

        try:
            return self._stub.CreateCampaign(
                campaigns_pb2.CreateCampaignRequest(
                    name=name,
                    base_link_id=base_link_id,
                    type=type,
                    utm_source=utm_source or "",
                    utm_medium=utm_medium or "",
                    utm_campaign=utm_campaign or "",
                )
            )
        except grpc.RpcError as e:
            raise wrap_error(e)

    def get(self, id: str) -> Any:
        """Get a campaign by ID."""
        from go2_sdk.gen.campaigns.v1 import campaigns_pb2

        try:
            return self._stub.GetCampaign(campaigns_pb2.GetCampaignRequest(id=id))
        except grpc.RpcError as e:
            raise wrap_error(e)

    def update(
        self,
        id: str,
        name: Optional[str] = None,
        utm_source: Optional[str] = None,
        utm_medium: Optional[str] = None,
        utm_campaign: Optional[str] = None,
    ) -> Any:
        """Update a campaign."""
        from go2_sdk.gen.campaigns.v1 import campaigns_pb2

        request = campaigns_pb2.UpdateCampaignRequest(id=id)
        if name is not None:
            request.name = name
        if utm_source is not None:
            request.utm_source = utm_source
        if utm_medium is not None:
            request.utm_medium = utm_medium
        if utm_campaign is not None:
            request.utm_campaign = utm_campaign

        try:
            return self._stub.UpdateCampaign(request)
        except grpc.RpcError as e:
            raise wrap_error(e)

    def delete(self, id: str) -> bool:
        """Delete a campaign."""
        from go2_sdk.gen.campaigns.v1 import campaigns_pb2

        try:
            response = self._stub.DeleteCampaign(
                campaigns_pb2.DeleteCampaignRequest(id=id)
            )
            return response.success
        except grpc.RpcError as e:
            raise wrap_error(e)

    def generate_links(self, id: str, recipients: List[Dict[str, str]]) -> Any:
        """Generate unique trackable links for recipients."""
        from go2_sdk.gen.campaigns.v1 import campaigns_pb2

        recipient_msgs = [
            campaigns_pb2.Recipient(
                identifier=r.get("identifier", ""),
                metadata=r.get("metadata", {}),
            )
            for r in recipients
        ]

        try:
            return self._stub.GenerateLinks(
                campaigns_pb2.GenerateLinksRequest(
                    campaign_id=id, recipients=recipient_msgs
                )
            )
        except grpc.RpcError as e:
            raise wrap_error(e)

    def list_links(
        self, id: str, page: int = 1, per_page: int = 100
    ) -> Any:
        """List campaign links."""
        from go2_sdk.gen.campaigns.v1 import campaigns_pb2

        try:
            return self._stub.ListCampaignLinks(
                campaigns_pb2.ListCampaignLinksRequest(
                    campaign_id=id, page=page, per_page=per_page
                )
            )
        except grpc.RpcError as e:
            raise wrap_error(e)

    def get_stats(self, id: str) -> Any:
        """Get campaign statistics."""
        from go2_sdk.gen.campaigns.v1 import campaigns_pb2

        try:
            return self._stub.GetCampaignStats(
                campaigns_pb2.GetCampaignStatsRequest(campaign_id=id)
            )
        except grpc.RpcError as e:
            raise wrap_error(e)

    def export_links(self, id: str, format: str = "csv") -> Any:
        """Export campaign links."""
        from go2_sdk.gen.campaigns.v1 import campaigns_pb2

        try:
            return self._stub.ExportLinks(
                campaigns_pb2.ExportLinksRequest(campaign_id=id, format=format)
            )
        except grpc.RpcError as e:
            raise wrap_error(e)


class Go2Client:
    """
    Go2 gRPC API Client.

    Example:
        with Go2Client(api_key="go2_xxx") as client:
            # Links
            links = client.links.list()
            link = client.links.create(slug="myapp", ios_url="...", android_url="...")

            # Analytics
            stats = client.analytics.get_stats(link_id="...")

            # Domains
            domains = client.domains.list()

            # QR Codes
            qr = client.qr.generate(link_id="...")

            # Integrations
            integrations = client.integrations.list()

            # Campaigns
            campaigns = client.campaigns.list()

    Args:
        api_key: Your Go2 API key (required)
        endpoint: gRPC endpoint (default: grpc.go2.ge:443)
        insecure: Use insecure connection for local development
    """

    def __init__(
        self,
        api_key: str,
        endpoint: str = DEFAULT_ENDPOINT,
        insecure: bool = False,
    ):
        if not api_key:
            raise ValueError("API key is required")

        # Create channel
        if insecure:
            channel = grpc.insecure_channel(endpoint)
        else:
            credentials = grpc.ssl_channel_credentials()
            channel = grpc.secure_channel(endpoint, credentials)

        # Add auth interceptor
        interceptor = _AuthInterceptor(api_key)
        self._channel = grpc.intercept_channel(channel, interceptor)

        # Import generated code and create service clients
        from go2_sdk.gen.integrations.v1 import integrations_pb2_grpc
        from go2_sdk.gen.links.v1 import links_pb2_grpc
        from go2_sdk.gen.analytics.v1 import analytics_pb2_grpc
        from go2_sdk.gen.domains.v1 import domains_pb2_grpc
        from go2_sdk.gen.qr.v1 import qr_pb2_grpc
        from go2_sdk.gen.campaigns.v1 import campaigns_pb2_grpc

        # Initialize all services
        self.integrations = IntegrationsService(
            integrations_pb2_grpc.IntegrationServiceStub(self._channel)
        )
        self.links = LinksService(
            links_pb2_grpc.LinkServiceStub(self._channel)
        )
        self.analytics = AnalyticsService(
            analytics_pb2_grpc.AnalyticsServiceStub(self._channel)
        )
        self.domains = DomainsService(
            domains_pb2_grpc.DomainServiceStub(self._channel)
        )
        self.qr = QRService(
            qr_pb2_grpc.QRServiceStub(self._channel)
        )
        self.campaigns = CampaignsService(
            campaigns_pb2_grpc.CampaignServiceStub(self._channel)
        )

    def close(self) -> None:
        """Close the client connection."""
        self._channel.close()

    def __enter__(self) -> "Go2Client":
        return self

    def __exit__(self, exc_type: Any, exc_val: Any, exc_tb: Any) -> None:
        self.close()



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from domains.v1 import domains_pb2 as domains_dot_v1_dot_domains__pb2

GRPC_GENERATED_VERSION = '1.78.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in domains/v1/domains_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class DomainServiceStub(object):
    """DomainService handles custom domain management
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListDomains = channel.unary_unary(
                '/domains.v1.DomainService/ListDomains',
                request_serializer=domains_dot_v1_dot_domains__pb2.ListDomainsRequest.SerializeToString,
                response_deserializer=domains_dot_v1_dot_domains__pb2.ListDomainsResponse.FromString,
                _registered_method=True)
        self.CreateDomain = channel.unary_unary(
                '/domains.v1.DomainService/CreateDomain',
                request_serializer=domains_dot_v1_dot_domains__pb2.CreateDomainRequest.SerializeToString,
                response_deserializer=domains_dot_v1_dot_domains__pb2.CreateDomainResponse.FromString,
                _registered_method=True)
        self.GetDomain = channel.unary_unary(
                '/domains.v1.DomainService/GetDomain',
                request_serializer=domains_dot_v1_dot_domains__pb2.GetDomainRequest.SerializeToString,
                response_deserializer=domains_dot_v1_dot_domains__pb2.Domain.FromString,
                _registered_method=True)
        self.VerifyDomain = channel.unary_unary(
                '/domains.v1.DomainService/VerifyDomain',
                request_serializer=domains_dot_v1_dot_domains__pb2.VerifyDomainRequest.SerializeToString,
                response_deserializer=domains_dot_v1_dot_domains__pb2.Domain.FromString,
                _registered_method=True)
        self.DeleteDomain = channel.unary_unary(
                '/domains.v1.DomainService/DeleteDomain',
                request_serializer=domains_dot_v1_dot_domains__pb2.DeleteDomainRequest.SerializeToString,
                response_deserializer=domains_dot_v1_dot_domains__pb2.DeleteDomainResponse.FromString,
                _registered_method=True)


class DomainServiceServicer(object):
    """DomainService handles custom domain management
    """

    def ListDomains(self, request, context):
        """List all custom domains
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDomain(self, request, context):
        """Add a new custom domain
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDomain(self, request, context):
        """Get a specific domain
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VerifyDomain(self, request, context):
        """Verify a domain
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDomain(self, request, context):
        """Delete a domain
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DomainServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListDomains': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDomains,
                    request_deserializer=domains_dot_v1_dot_domains__pb2.ListDomainsRequest.FromString,
                    response_serializer=domains_dot_v1_dot_domains__pb2.ListDomainsResponse.SerializeToString,
            ),
            'CreateDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDomain,
                    request_deserializer=domains_dot_v1_dot_domains__pb2.CreateDomainRequest.FromString,
                    response_serializer=domains_dot_v1_dot_domains__pb2.CreateDomainResponse.SerializeToString,
            ),
            'GetDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDomain,
                    request_deserializer=domains_dot_v1_dot_domains__pb2.GetDomainRequest.FromString,
                    response_serializer=domains_dot_v1_dot_domains__pb2.Domain.SerializeToString,
            ),
            'VerifyDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.VerifyDomain,
                    request_deserializer=domains_dot_v1_dot_domains__pb2.VerifyDomainRequest.FromString,
                    response_serializer=domains_dot_v1_dot_domains__pb2.Domain.SerializeToString,
            ),
            'DeleteDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDomain,
                    request_deserializer=domains_dot_v1_dot_domains__pb2.DeleteDomainRequest.FromString,
                    response_serializer=domains_dot_v1_dot_domains__pb2.DeleteDomainResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'domains.v1.DomainService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('domains.v1.DomainService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class DomainService(object):
    """DomainService handles custom domain management
    """

    @staticmethod
    def ListDomains(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/domains.v1.DomainService/ListDomains',
            domains_dot_v1_dot_domains__pb2.ListDomainsRequest.SerializeToString,
            domains_dot_v1_dot_domains__pb2.ListDomainsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/domains.v1.DomainService/CreateDomain',
            domains_dot_v1_dot_domains__pb2.CreateDomainRequest.SerializeToString,
            domains_dot_v1_dot_domains__pb2.CreateDomainResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/domains.v1.DomainService/GetDomain',
            domains_dot_v1_dot_domains__pb2.GetDomainRequest.SerializeToString,
            domains_dot_v1_dot_domains__pb2.Domain.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def VerifyDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/domains.v1.DomainService/VerifyDomain',
            domains_dot_v1_dot_domains__pb2.VerifyDomainRequest.SerializeToString,
            domains_dot_v1_dot_domains__pb2.Domain.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/domains.v1.DomainService/DeleteDomain',
            domains_dot_v1_dot_domains__pb2.DeleteDomainRequest.SerializeToString,
            domains_dot_v1_dot_domains__pb2.DeleteDomainResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from integrations.v1 import integrations_pb2 as integrations_dot_v1_dot_integrations__pb2

GRPC_GENERATED_VERSION = '1.78.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in integrations/v1/integrations_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class IntegrationServiceStub(object):
    """IntegrationService handles third-party integration management
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListIntegrations = channel.unary_unary(
                '/integrations.v1.IntegrationService/ListIntegrations',
                request_serializer=integrations_dot_v1_dot_integrations__pb2.ListIntegrationsRequest.SerializeToString,
                response_deserializer=integrations_dot_v1_dot_integrations__pb2.ListIntegrationsResponse.FromString,
                _registered_method=True)
        self.CreateIntegration = channel.unary_unary(
                '/integrations.v1.IntegrationService/CreateIntegration',
                request_serializer=integrations_dot_v1_dot_integrations__pb2.CreateIntegrationRequest.SerializeToString,
                response_deserializer=integrations_dot_v1_dot_integrations__pb2.Integration.FromString,
                _registered_method=True)
        self.GetIntegration = channel.unary_unary(
                '/integrations.v1.IntegrationService/GetIntegration',
                request_serializer=integrations_dot_v1_dot_integrations__pb2.GetIntegrationRequest.SerializeToString,
                response_deserializer=integrations_dot_v1_dot_integrations__pb2.Integration.FromString,
                _registered_method=True)
        self.UpdateIntegration = channel.unary_unary(
                '/integrations.v1.IntegrationService/UpdateIntegration',
                request_serializer=integrations_dot_v1_dot_integrations__pb2.UpdateIntegrationRequest.SerializeToString,
                response_deserializer=integrations_dot_v1_dot_integrations__pb2.Integration.FromString,
                _registered_method=True)
        self.DeleteIntegration = channel.unary_unary(
                '/integrations.v1.IntegrationService/DeleteIntegration',
                request_serializer=integrations_dot_v1_dot_integrations__pb2.DeleteIntegrationRequest.SerializeToString,
                response_deserializer=integrations_dot_v1_dot_integrations__pb2.DeleteIntegrationResponse.FromString,
                _registered_method=True)
        self.TestIntegration = channel.unary_unary(
                '/integrations.v1.IntegrationService/TestIntegration',
                request_serializer=integrations_dot_v1_dot_integrations__pb2.TestIntegrationRequest.SerializeToString,
                response_deserializer=integrations_dot_v1_dot_integrations__pb2.TestIntegrationResponse.FromString,
                _registered_method=True)
        self.GetIntegrationTypes = channel.unary_unary(
                '/integrations.v1.IntegrationService/GetIntegrationTypes',
                request_serializer=integrations_dot_v1_dot_integrations__pb2.GetIntegrationTypesRequest.SerializeToString,
                response_deserializer=integrations_dot_v1_dot_integrations__pb2.GetIntegrationTypesResponse.FromString,
                _registered_method=True)


class IntegrationServiceServicer(object):
    """IntegrationService handles third-party integration management
    """

    def ListIntegrations(self, request, context):
        """List all integrations for the authenticated user
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateIntegration(self, request, context):
        """Create a new integration
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIntegration(self, request, context):
        """Get a specific integration by ID
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateIntegration(self, request, context):
        """Update an existing integration
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteIntegration(self, request, context):
        """Delete an integration
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TestIntegration(self, request, context):
        """Test an integration by sending a test notification
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIntegrationTypes(self, request, context):
        """Get available integration types and events
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_IntegrationServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListIntegrations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListIntegrations,
                    request_deserializer=integrations_dot_v1_dot_integrations__pb2.ListIntegrationsRequest.FromString,
                    response_serializer=integrations_dot_v1_dot_integrations__pb2.ListIntegrationsResponse.SerializeToString,
            ),
            'CreateIntegration': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateIntegration,
                    request_deserializer=integrations_dot_v1_dot_integrations__pb2.CreateIntegrationRequest.FromString,
                    response_serializer=integrations_dot_v1_dot_integrations__pb2.Integration.SerializeToString,
            ),
            'GetIntegration': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIntegration,
                    request_deserializer=integrations_dot_v1_dot_integrations__pb2.GetIntegrationRequest.FromString,
                    response_serializer=integrations_dot_v1_dot_integrations__pb2.Integration.SerializeToString,
            ),
            'UpdateIntegration': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateIntegration,
                    request_deserializer=integrations_dot_v1_dot_integrations__pb2.UpdateIntegrationRequest.FromString,
                    response_serializer=integrations_dot_v1_dot_integrations__pb2.Integration.SerializeToString,
            ),
            'DeleteIntegration': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteIntegration,
                    request_deserializer=integrations_dot_v1_dot_integrations__pb2.DeleteIntegrationRequest.FromString,
                    response_serializer=integrations_dot_v1_dot_integrations__pb2.DeleteIntegrationResponse.SerializeToString,
            ),
            'TestIntegration': grpc.unary_unary_rpc_method_handler(
                    servicer.TestIntegration,
                    request_deserializer=integrations_dot_v1_dot_integrations__pb2.TestIntegrationRequest.FromString,
                    response_serializer=integrations_dot_v1_dot_integrations__pb2.TestIntegrationResponse.SerializeToString,
            ),
            'GetIntegrationTypes': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIntegrationTypes,
                    request_deserializer=integrations_dot_v1_dot_integrations__pb2.GetIntegrationTypesRequest.FromString,
                    response_serializer=integrations_dot_v1_dot_integrations__pb2.GetIntegrationTypesResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'integrations.v1.IntegrationService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('integrations.v1.IntegrationService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class IntegrationService(object):
    """IntegrationService handles third-party integration management
    """

    @staticmethod
    def ListIntegrations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/integrations.v1.IntegrationService/ListIntegrations',
            integrations_dot_v1_dot_integrations__pb2.ListIntegrationsRequest.SerializeToString,
            integrations_dot_v1_dot_integrations__pb2.ListIntegrationsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateIntegration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/integrations.v1.IntegrationService/CreateIntegration',
            integrations_dot_v1_dot_integrations__pb2.CreateIntegrationRequest.SerializeToString,
            integrations_dot_v1_dot_integrations__pb2.Integration.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetIntegration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/integrations.v1.IntegrationService/GetIntegration',
            integrations_dot_v1_dot_integrations__pb2.GetIntegrationRequest.SerializeToString,
            integrations_dot_v1_dot_integrations__pb2.Integration.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateIntegration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/integrations.v1.IntegrationService/UpdateIntegration',
            integrations_dot_v1_dot_integrations__pb2.UpdateIntegrationRequest.SerializeToString,
            integrations_dot_v1_dot_integrations__pb2.Integration.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteIntegration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/integrations.v1.IntegrationService/DeleteIntegration',
            integrations_dot_v1_dot_integrations__pb2.DeleteIntegrationRequest.SerializeToString,
            integrations_dot_v1_dot_integrations__pb2.DeleteIntegrationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def TestIntegration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/integrations.v1.IntegrationService/TestIntegration',
            integrations_dot_v1_dot_integrations__pb2.TestIntegrationRequest.SerializeToString,
            integrations_dot_v1_dot_integrations__pb2.TestIntegrationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetIntegrationTypes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/integrations.v1.IntegrationService/GetIntegrationTypes',
            integrations_dot_v1_dot_integrations__pb2.GetIntegrationTypesRequest.SerializeToString,
            integrations_dot_v1_dot_integrations__pb2.GetIntegrationTypesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



import datetime

from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DomainStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    DOMAIN_STATUS_UNSPECIFIED: _ClassVar[DomainStatus]
    DOMAIN_STATUS_PENDING: _ClassVar[DomainStatus]
    DOMAIN_STATUS_VERIFYING: _ClassVar[DomainStatus]
    DOMAIN_STATUS_ACTIVE: _ClassVar[DomainStatus]
    DOMAIN_STATUS_FAILED: _ClassVar[DomainStatus]

class SSLStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    SSL_STATUS_UNSPECIFIED: _ClassVar[SSLStatus]
    SSL_STATUS_PENDING: _ClassVar[SSLStatus]
    SSL_STATUS_PROVISIONING: _ClassVar[SSLStatus]
    SSL_STATUS_ACTIVE: _ClassVar[SSLStatus]
    SSL_STATUS_FAILED: _ClassVar[SSLStatus]
DOMAIN_STATUS_UNSPECIFIED: DomainStatus
DOMAIN_STATUS_PENDING: DomainStatus
DOMAIN_STATUS_VERIFYING: DomainStatus
DOMAIN_STATUS_ACTIVE: DomainStatus
DOMAIN_STATUS_FAILED: DomainStatus
SSL_STATUS_UNSPECIFIED: SSLStatus
SSL_STATUS_PENDING: SSLStatus
SSL_STATUS_PROVISIONING: SSLStatus
SSL_STATUS_ACTIVE: SSLStatus
SSL_STATUS_FAILED: SSLStatus

class Domain(_message.Message):
    __slots__ = ("id", "user_id", "domain", "status", "verification_token", "verified_at", "ssl_status", "cloudflare_hostname_id", "created_at", "updated_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    VERIFICATION_TOKEN_FIELD_NUMBER: _ClassVar[int]
    VERIFIED_AT_FIELD_NUMBER: _ClassVar[int]
    SSL_STATUS_FIELD_NUMBER: _ClassVar[int]
    CLOUDFLARE_HOSTNAME_ID_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    user_id: str
    domain: str
    status: DomainStatus
    verification_token: str
    verified_at: _timestamp_pb2.Timestamp
    ssl_status: SSLStatus
    cloudflare_hostname_id: str
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., user_id: _Optional[str] = ..., domain: _Optional[str] = ..., status: _Optional[_Union[DomainStatus, str]] = ..., verification_token: _Optional[str] = ..., verified_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., ssl_status: _Optional[_Union[SSLStatus, str]] = ..., cloudflare_hostname_id: _Optional[str] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class DNSRecord(_message.Message):
    __slots__ = ("type", "name", "value")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    type: str
    name: str
    value: str
    def __init__(self, type: _Optional[str] = ..., name: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...

class ListDomainsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListDomainsResponse(_message.Message):
    __slots__ = ("domains",)
    DOMAINS_FIELD_NUMBER: _ClassVar[int]
    domains: _containers.RepeatedCompositeFieldContainer[Domain]
    def __init__(self, domains: _Optional[_Iterable[_Union[Domain, _Mapping]]] = ...) -> None: ...

class CreateDomainRequest(_message.Message):
    __slots__ = ("domain",)
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    domain: str
    def __init__(self, domain: _Optional[str] = ...) -> None: ...

class CreateDomainResponse(_message.Message):
    __slots__ = ("domain", "dns_records")
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    DNS_RECORDS_FIELD_NUMBER: _ClassVar[int]
    domain: Domain
    dns_records: _containers.RepeatedCompositeFieldContainer[DNSRecord]
    def __init__(self, domain: _Optional[_Union[Domain, _Mapping]] = ..., dns_records: _Optional[_Iterable[_Union[DNSRecord, _Mapping]]] = ...) -> None: ...

class GetDomainRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class VerifyDomainRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeleteDomainRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeleteDomainResponse(_message.Message):
    __slots__ = ("success", "message")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    success: bool
    message: str
    def __init__(self, success: bool = ..., message: _Optional[str] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class GenerateQRRequest(_message.Message):
    __slots__ = ("link_id", "size", "format", "foreground_color", "background_color", "logo_url")
    LINK_ID_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    FOREGROUND_COLOR_FIELD_NUMBER: _ClassVar[int]
    BACKGROUND_COLOR_FIELD_NUMBER: _ClassVar[int]
    LOGO_URL_FIELD_NUMBER: _ClassVar[int]
    link_id: str
    size: int
    format: str
    foreground_color: str
    background_color: str
    logo_url: str
    def __init__(self, link_id: _Optional[str] = ..., size: _Optional[int] = ..., format: _Optional[str] = ..., foreground_color: _Optional[str] = ..., background_color: _Optional[str] = ..., logo_url: _Optional[str] = ...) -> None: ...

class GenerateQRResponse(_message.Message):
    __slots__ = ("url", "size", "format")
    URL_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    url: str
    size: int
    format: str
    def __init__(self, url: _Optional[str] = ..., size: _Optional[int] = ..., format: _Optional[str] = ...) -> None: ...



import datetime

from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class IntegrationType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    INTEGRATION_TYPE_UNSPECIFIED: _ClassVar[IntegrationType]
    INTEGRATION_TYPE_SLACK: _ClassVar[IntegrationType]
    INTEGRATION_TYPE_DISCORD: _ClassVar[IntegrationType]
    INTEGRATION_TYPE_TELEGRAM: _ClassVar[IntegrationType]
    INTEGRATION_TYPE_SEGMENT: _ClassVar[IntegrationType]
    INTEGRATION_TYPE_ZAPIER: _ClassVar[IntegrationType]
INTEGRATION_TYPE_UNSPECIFIED: IntegrationType
INTEGRATION_TYPE_SLACK: IntegrationType
INTEGRATION_TYPE_DISCORD: IntegrationType
INTEGRATION_TYPE_TELEGRAM: IntegrationType
INTEGRATION_TYPE_SEGMENT: IntegrationType
INTEGRATION_TYPE_ZAPIER: IntegrationType

class Integration(_message.Message):
    __slots__ = ("id", "user_id", "type", "name", "config", "events", "is_active", "last_triggered_at", "trigger_count", "created_at", "updated_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    IS_ACTIVE_FIELD_NUMBER: _ClassVar[int]
    LAST_TRIGGERED_AT_FIELD_NUMBER: _ClassVar[int]
    TRIGGER_COUNT_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    user_id: str
    type: IntegrationType
    name: str
    config: IntegrationConfig
    events: _containers.RepeatedScalarFieldContainer[str]
    is_active: bool
    last_triggered_at: _timestamp_pb2.Timestamp
    trigger_count: int
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., user_id: _Optional[str] = ..., type: _Optional[_Union[IntegrationType, str]] = ..., name: _Optional[str] = ..., config: _Optional[_Union[IntegrationConfig, _Mapping]] = ..., events: _Optional[_Iterable[str]] = ..., is_active: bool = ..., last_triggered_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., trigger_count: _Optional[int] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class IntegrationConfig(_message.Message):
    __slots__ = ("webhook_url", "channel", "bot_token", "chat_id", "write_key")
    WEBHOOK_URL_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_FIELD_NUMBER: _ClassVar[int]
    BOT_TOKEN_FIELD_NUMBER: _ClassVar[int]
    CHAT_ID_FIELD_NUMBER: _ClassVar[int]
    WRITE_KEY_FIELD_NUMBER: _ClassVar[int]
    webhook_url: str
    channel: str
    bot_token: str
    chat_id: str
    write_key: str
    def __init__(self, webhook_url: _Optional[str] = ..., channel: _Optional[str] = ..., bot_token: _Optional[str] = ..., chat_id: _Optional[str] = ..., write_key: _Optional[str] = ...) -> None: ...

class ListIntegrationsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListIntegrationsResponse(_message.Message):
    __slots__ = ("integrations",)
    INTEGRATIONS_FIELD_NUMBER: _ClassVar[int]
    integrations: _containers.RepeatedCompositeFieldContainer[Integration]
    def __init__(self, integrations: _Optional[_Iterable[_Union[Integration, _Mapping]]] = ...) -> None: ...

class CreateIntegrationRequest(_message.Message):
    __slots__ = ("type", "name", "config", "events")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    type: IntegrationType
    name: str
    config: IntegrationConfig
    events: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, type: _Optional[_Union[IntegrationType, str]] = ..., name: _Optional[str] = ..., config: _Optional[_Union[IntegrationConfig, _Mapping]] = ..., events: _Optional[_Iterable[str]] = ...) -> None: ...

class GetIntegrationRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class UpdateIntegrationRequest(_message.Message):
    __slots__ = ("id", "name", "config", "events", "is_active")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    IS_ACTIVE_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    config: IntegrationConfig
    events: _containers.RepeatedScalarFieldContainer[str]
    is_active: bool
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., config: _Optional[_Union[IntegrationConfig, _Mapping]] = ..., events: _Optional[_Iterable[str]] = ..., is_active: bool = ...) -> None: ...

class DeleteIntegrationRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeleteIntegrationResponse(_message.Message):
    __slots__ = ("success",)
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: bool = ...) -> None: ...

class TestIntegrationRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class TestIntegrationResponse(_message.Message):
    __slots__ = ("success", "message")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    success: bool
    message: str
    def __init__(self, success: bool = ..., message: _Optional[str] = ...) -> None: ...

class GetIntegrationTypesRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetIntegrationTypesResponse(_message.Message):
    __slots__ = ("types", "events")
    TYPES_FIELD_NUMBER: _ClassVar[int]
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    types: _containers.RepeatedCompositeFieldContainer[IntegrationTypeInfo]
    events: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, types: _Optional[_Iterable[_Union[IntegrationTypeInfo, _Mapping]]] = ..., events: _Optional[_Iterable[str]] = ...) -> None: ...

class IntegrationTypeInfo(_message.Message):
    __slots__ = ("type", "name", "description", "icon", "available", "config_fields")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    ICON_FIELD_NUMBER: _ClassVar[int]
    AVAILABLE_FIELD_NUMBER: _ClassVar[int]
    CONFIG_FIELDS_FIELD_NUMBER: _ClassVar[int]
    type: IntegrationType
    name: str
    description: str
    icon: str
    available: bool
    config_fields: _containers.RepeatedCompositeFieldContainer[ConfigField]
    def __init__(self, type: _Optional[_Union[IntegrationType, str]] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., icon: _Optional[str] = ..., available: bool = ..., config_fields: _Optional[_Iterable[_Union[ConfigField, _Mapping]]] = ...) -> None: ...

class ConfigField(_message.Message):
    __slots__ = ("name", "label", "field_type", "required", "placeholder", "help_text")
    NAME_FIELD_NUMBER: _ClassVar[int]
    LABEL_FIELD_NUMBER: _ClassVar[int]
    FIELD_TYPE_FIELD_NUMBER: _ClassVar[int]
    REQUIRED_FIELD_NUMBER: _ClassVar[int]
    PLACEHOLDER_FIELD_NUMBER: _ClassVar[int]
    HELP_TEXT_FIELD_NUMBER: _ClassVar[int]
    name: str
    label: str
    field_type: str
    required: bool
    placeholder: str
    help_text: str
    def __init__(self, name: _Optional[str] = ..., label: _Optional[str] = ..., field_type: _Optional[str] = ..., required: bool = ..., placeholder: _Optional[str] = ..., help_text: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: domains/v1/domains.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'domains/v1/domains.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x64omains/v1/domains.proto\x12\ndomains.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xec\x02\n\x06\x44omain\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x0e\n\x06\x64omain\x18\x03 \x01(\t\x12(\n\x06status\x18\x04 \x01(\x0e\x32\x18.domains.v1.DomainStatus\x12\x1a\n\x12verification_token\x18\x05 \x01(\t\x12\x34\n\x0bverified_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x12)\n\nssl_status\x18\x07 \x01(\x0e\x32\x15.domains.v1.SSLStatus\x12\x1e\n\x16\x63loudflare_hostname_id\x18\x08 \x01(\t\x12.\n\ncreated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x0e\n\x0c_verified_at\"6\n\tDNSRecord\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\x14\n\x12ListDomainsRequest\":\n\x13ListDomainsResponse\x12#\n\x07\x64omains\x18\x01 \x03(\x0b\x32\x12.domains.v1.Domain\"%\n\x13\x43reateDomainRequest\x12\x0e\n\x06\x64omain\x18\x01 \x01(\t\"f\n\x14\x43reateDomainResponse\x12\"\n\x06\x64omain\x18\x01 \x01(\x0b\x32\x12.domains.v1.Domain\x12*\n\x0b\x64ns_records\x18\x02 \x03(\x0b\x32\x15.domains.v1.DNSRecord\"\x1e\n\x10GetDomainRequest\x12\n\n\x02id\x18\x01 \x01(\t\"!\n\x13VerifyDomainRequest\x12\n\n\x02id\x18\x01 \x01(\t\"!\n\x13\x44\x65leteDomainRequest\x12\n\n\x02id\x18\x01 \x01(\t\"8\n\x14\x44\x65leteDomainResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t*\x99\x01\n\x0c\x44omainStatus\x12\x1d\n\x19\x44OMAIN_STATUS_UNSPECIFIED\x10\x00\x12\x19\n\x15\x44OMAIN_STATUS_PENDING\x10\x01\x12\x1b\n\x17\x44OMAIN_STATUS_VERIFYING\x10\x02\x12\x18\n\x14\x44OMAIN_STATUS_ACTIVE\x10\x03\x12\x18\n\x14\x44OMAIN_STATUS_FAILED\x10\x04*\x8a\x01\n\tSSLStatus\x12\x1a\n\x16SSL_STATUS_UNSPECIFIED\x10\x00\x12\x16\n\x12SSL_STATUS_PENDING\x10\x01\x12\x1b\n\x17SSL_STATUS_PROVISIONING\x10\x02\x12\x15\n\x11SSL_STATUS_ACTIVE\x10\x03\x12\x15\n\x11SSL_STATUS_FAILED\x10\x04\x32\x89\x03\n\rDomainService\x12N\n\x0bListDomains\x12\x1e.domains.v1.ListDomainsRequest\x1a\x1f.domains.v1.ListDomainsResponse\x12Q\n\x0c\x43reateDomain\x12\x1f.domains.v1.CreateDomainRequest\x1a .domains.v1.CreateDomainResponse\x12=\n\tGetDomain\x12\x1c.domains.v1.GetDomainRequest\x1a\x12.domains.v1.Domain\x12\x43\n\x0cVerifyDomain\x12\x1f.domains.v1.VerifyDomainRequest\x1a\x12.domains.v1.Domain\x12Q\n\x0c\x44\x65leteDomain\x12\x1f.domains.v1.DeleteDomainRequest\x1a .domains.v1.DeleteDomainResponseB5Z3github.com/gosms-ge/go2-sdk/go/domains/v1;domainsv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'domains.v1.domains_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/gosms-ge/go2-sdk/go/domains/v1;domainsv1'
  _globals['_DOMAINSTATUS']._serialized_start=882
  _globals['_DOMAINSTATUS']._serialized_end=1035
  _globals['_SSLSTATUS']._serialized_start=1038
  _globals['_SSLSTATUS']._serialized_end=1176
  _globals['_DOMAIN']._serialized_start=74
  _globals['_DOMAIN']._serialized_end=438
  _globals['_DNSRECORD']._serialized_start=440
  _globals['_DNSRECORD']._serialized_end=494
  _globals['_LISTDOMAINSREQUEST']._serialized_start=496
  _globals['_LISTDOMAINSREQUEST']._serialized_end=516
  _globals['_LISTDOMAINSRESPONSE']._serialized_start=518
  _globals['_LISTDOMAINSRESPONSE']._serialized_end=576
  _globals['_CREATEDOMAINREQUEST']._serialized_start=578
  _globals['_CREATEDOMAINREQUEST']._serialized_end=615
  _globals['_CREATEDOMAINRESPONSE']._serialized_start=617
  _globals['_CREATEDOMAINRESPONSE']._serialized_end=719
  _globals['_GETDOMAINREQUEST']._serialized_start=721
  _globals['_GETDOMAINREQUEST']._serialized_end=751
  _globals['_VERIFYDOMAINREQUEST']._serialized_start=753
  _globals['_VERIFYDOMAINREQUEST']._serialized_end=786
  _globals['_DELETEDOMAINREQUEST']._serialized_start=788
  _globals['_DELETEDOMAINREQUEST']._serialized_end=821
  _globals['_DELETEDOMAINRESPONSE']._serialized_start=823
  _globals['_DELETEDOMAINRESPONSE']._serialized_end=879
  _globals['_DOMAINSERVICE']._serialized_start=1179
  _globals['_DOMAINSERVICE']._serialized_end=1572
# @@protoc_insertion_point(module_scope)
